@@ -50,7 +50,6 @@ class String(str):
         word = Word(alphanums+':<>.[]_-,=~/')
         conditional = Forward()
         conditional << (Optional("!")("negate") + word("cond") + Suppress('?') + Suppress('(') + OneOrMore(conditional ^ word)("expr") + Suppress(')')).setParseAction(cb_conditional)
-        #string = (function ^ word)
         string = word
         string_list = OneOrMore(conditional ^ string)
         s = ' '.join(string_list.parseString(self.__str__()))
@@ -107,7 +106,7 @@ class Provider(object):
                                            "FIXME: cache_root can be set in fetch call")
 
 class Core:
-    def __init__(self, core_file, cache_root='', build_root=''):
+    def __init__(self, core_file, cache_root=''):
         basename = os.path.basename(core_file)
 
         self.core_root = os.path.dirname(core_file)
@@ -311,7 +310,7 @@ class Core:
                 else:
                     default     = self.parameters[p].default
                 description = self.parameters[p].description
-                paramtype   = self.parameters[p].paramtype
+                paramtype   = self.parameters[p].paramtype.parse(flags)
 
                 if not datatype in ['bool', 'file', 'int', 'str']:
                     _s = "{} : Invalid datatype '{}' for parameter {}"
@@ -323,7 +322,7 @@ class Core:
                     raise SyntaxError(_s.format(self.name, paramtype, p))
                 parameters[p] = {
                     'datatype'  : str(self.parameters[p].datatype),
-                    'paramtype' : str(self.parameters[p].paramtype),
+                    'paramtype' : paramtype,
                 }
 
                 if description:
