@@ -65,7 +65,7 @@ def build(cm, args):
              'tool' : args.tool}
     run_backend(cm, not args.no_export,
                 do_configure, do_build, do_run,
-                flags, args.system, args.backendargs)
+                flags, None, args.system, args.backendargs, None)
 
 def pgm(cm, args):
     do_configure = False
@@ -75,7 +75,7 @@ def pgm(cm, args):
              'tool' : None}
     run_backend(cm, 'build',
                 do_configure, do_build, do_run,
-                flags, args.system, args.backendargs)
+                flags, None, args.system, args.backendargs, None)
 
 def fetch(cm, args):
     core = _get_core(cm, args.core)
@@ -113,6 +113,7 @@ def init(cm, args):
 
     xdg_data_home = os.environ.get('XDG_DATA_HOME') or \
              os.path.join(os.path.expanduser('~'), '.local/share')
+    library_root = os.path.join(xdg_data_home, 'fusesoc')
     _repo_paths = []
     for repo in REPOS:
         name = repo[0]
@@ -121,7 +122,7 @@ def init(cm, args):
                 'sync-type': 'git'
                 }
 
-        default_dir = os.path.join(xdg_data_home, name)
+        default_dir = os.path.join(library_root, name)
         prompt = 'Directory to use for {} ({}) [{}] : '
         if args.y:
             location = None
@@ -258,10 +259,10 @@ def run(cm, args):
     run_backend(cm,
                 not args.no_export,
                 do_configure, do_build, do_run,
-                flags, args.system, args.backendargs)
+                flags, args.system_name, args.system, args.backendargs, args.build_root)
 
 
-def run_backend(cm, export, do_configure, do_build, do_run, flags, system, backendargs):
+def run_backend(cm, export, do_configure, do_build, do_run, flags, system_name, system, backendargs, build_root_arg):
     tool_error = "No tool was supplied on command line or found in '{}' core description"
     core = _get_core(cm, system)
     try:
@@ -273,19 +274,23 @@ def run_backend(cm, export, do_configure, do_build, do_run, flags, system, backe
         logger.error(tool_error.format(system))
         exit(1)
     flags['tool'] = tool
+    build_root = build_root_arg or os.path.join(cm.config.build_root, core.name.sanitized_name)
+    logger.debug('Setting build_root to {}'.format(build_root))
     if export:
-        export_root = os.path.join(cm.config.build_root, core.name.sanitized_name, 'src')
+        export_root = os.path.join(build_root, 'src')
     else:
         export_root = None
     try:
-        work_root   = os.path.join(cm.config.build_root,
-                                   core.name.sanitized_name,
+        work_root   = os.path.join(build_root,
                                    core.get_work_root(flags))
     except SyntaxError as e:
         logger.error(e.msg)
         exit(1)
     eda_api_file = os.path.join(work_root,
                                 core.name.sanitized_name+'.eda.yml')
+    if not os.path.exists(eda_api_file):
+        do_configure = True
+
     if do_configure:
         try:
             cores = cm.get_depends(core.name, flags)
@@ -298,7 +303,8 @@ def run_backend(cm, export, do_configure, do_build, do_run, flags, system, backe
                                 cores,
                                 cache_root=cm.config.cache_root,
                                 work_root=work_root,
-                                export_root=export_root)
+                                export_root=export_root,
+                                system_name=system_name)
         except SyntaxError as e:
             logger.error(e.msg)
             exit(1)
@@ -310,8 +316,14 @@ def run_backend(cm, export, do_configure, do_build, do_run, flags, system, backe
     #Frontend/backend separation
 
     try:
-        backend = get_edatool(tool)(eda_api=edalizer.edalize,
+        if do_configure:
+            edam = edalizer.edalize
+        else:
+            import yaml
+            edam = yaml.safe_load(open(eda_api_file))
+        backend = get_edatool(tool)(edam=edam,
                                     work_root=work_root)
+
     except ImportError:
         logger.error('Backend "{}" not found'.format(tool))
         exit(1)
@@ -359,7 +371,7 @@ def sim(cm, args):
     }
     run_backend(cm, not args.no_export,
                 do_configure, do_build, do_run,
-                flags, args.system, args.backendargs)
+                flags, None, args.system, args.backendargs, None)
 
 def update(cm, args):
     libraries = args.libraries
@@ -538,11 +550,13 @@ def parse_args():
     # run subparser
     parser_run = subparsers.add_parser('run', help="Start a tool flow")
     parser_run.add_argument('--no-export', action='store_true', help='Reference source files from their current location instead of exporting to a build tree')
+    parser_run.add_argument('--build-root', help="Output directory for build. Defaults to build/$VLNV")
     parser_run.add_argument('--setup',  action='store_true', help="Execute setup stage")
     parser_run.add_argument('--build',  action='store_true', help="Execute build stage")
     parser_run.add_argument('--run'  ,  action='store_true', help="Execute run stage")
     parser_run.add_argument('--target', help='Override default target')
     parser_run.add_argument('--tool', help="Override default tool for target")
+    parser_run.add_argument('--system-name', help='Override default VLNV name for system')
     parser_run.add_argument('system', help='Select a system to operate on')
     parser_run.add_argument('backendargs', nargs=argparse.REMAINDER, help="arguments to be sent to backend")
     parser_run.set_defaults(func=run)
